@@ -117,6 +117,9 @@
 #' (multivariate repeated measures). \cr
 #' Ecosystem functions may be stored in a long or wide format while repeated measures must be stored
 #' in a long format. \cr
+#' Additionally, by calling the function DImultiApp(), you can interact with the
+#' provided R Shiny app, which aids in fitting and visualising multivariate or
+#' repeated measures models through a user-friendly interface. \cr
 #'
 #' \strong{Introduction to multivariate & repeated measures Diversity-Interactions models} \cr
 #'
@@ -262,7 +265,8 @@
 #'
 #' @seealso
 #' This package:
-#'    \code{\link{DImulti}} \cr
+#'    \code{\link{DImulti}},
+#'    \code{\link{DImultiApp}} \cr
 #'    Example datasets:
 #'    \code{\link[DImodelsMulti]{dataBEL}},
 #'    \code{\link[DImodelsMulti]{dataSWE}},
@@ -1401,6 +1405,7 @@ estimate_theta <- function(y, eco_func, time, unit_IDs,
   }
   else if(methodTheta == "single")
   {
+
     theta_Est <- function(thetaVal)
     {
       thetaVal_temp <- rep(1, times = nFunc)
@@ -1435,13 +1440,22 @@ estimate_theta <- function(y, eco_func, time, unit_IDs,
 
     if(!is.null(extra_fixed))
     {
-      extra_fixed_temp <- deparse(extra_fixed)
 
       #Remove any mention of ecosystem functions from extra_fixed
-      extraTemp <- gsub(paste0(eco_func[1], "\\s*[:|\\*]"), "", extra_fixed_temp)
+      extraTemp <- gsub(paste0(eco_func[1], "\\s*[:|\\*]"), "", extra_fixed)
       extraTemp <- gsub(paste0("[:|\\*]\\s*", eco_func[1]), "", extraTemp)
       extraTemp <- gsub(paste0("\\+\\s*", eco_func[1]), "", extraTemp)
 
+      #Remove beginning instance of + operator & insert ~
+      if(trimws(substring(extraTemp, 1, 1)) == "+")
+      {
+        extraTemp <- trimws(substring(extraTemp, 2))
+      }
+      else if(trimws(substring(extraTemp, 1, 1)) %in% c("*", ":", "-"))
+      {
+        extraTemp <- paste0("1", extraTemp)
+      }
+      extraTemp <- paste0("~", extraTemp)
       extraTemp <- stats::formula(extraTemp)
     }
     else
